==> xoonips-3.30.tar.gz: xoonips-3.30/xoonips/admin/maintenance.php <==
<?php
// $Revision: 1.1.2.8 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

require_once( '../../../include/cp_header.php' );

// load common file.
include 'actions/common.inc.php';

// resources
xoonips_admin_include_resource( 'xoonips', 'modinfo.php' );

// page definition
$pages = array(); 
$pages['main'] = array( 'default' );
$pages['account'] = array( 'default', 'modify', 'update', 'dconfirm', 'activate', 'add' );
$pages['item'] = array( 'default', 'wupdate', 'dupdate' );
$pages['ranking'] = array( 'default', 'download', 'upload', 'clear' );
$pages['position'] = array( 'default', 'update' );
$pages['filesearch'] = array( 'default', 'rescan' );
$pages['oaipmh'] = array( 'default' );

// initialize
xoonips_admin_initialize( __FILE__, 'maintenance', $pages );

// call action file
include $xoonips_admin['myaction_path'];

?>

==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/admin/maintenance.php <==
<?php
// $Revision: 1.1.2.9 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

require_once( '../../../include/cp_header.php' );

// load common file.
include 'actions/common.inc.php';

// resources
xoonips_admin_include_resource( 'xoonips', 'modinfo.php' );

// page definition
$pages = array(); 
$pages['main'] = array();
$pages['account'] = array(
  'get' => array( 'modify', 'add' ),
  'post' => array( 'update', 'dconfirm', 'activate' ),
);
$pages['item'] = array(
  'get' => array( 'withdraw', 'delete' ),
  'post' => array( 'wupdate', 'dupdate' ),
);
$pages['ranking'] = array(
  'post' => array( 'download', 'upload', 'clear' ),
);
$pages['position'] = array(
  'post' => array( 'update' ),
);
$pages['filesearch'] = array(
  'post' => array( 'rescan' ),
);
$pages['oaipmh'] = array();

// initialize
xoonips_admin_initialize( __FILE__, 'maintenance', $pages );

// call action file
include $xoonips_admin['myaction_path'];

?>
